@@ -7,8 +7,10 @@
 #include <ctype.h>
 #include <math.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <memory.h>
+# if !defined( WIN32 )
+#   include <unistd.h>
+# endif
 
 #define TYPE_TAG_IS_OPEN   100
 #define TYPE_TAG_IS_CLOSE  200
